//-----------------------------------------------------------------------
//	File:		$RCSfile: Lab3Compare.v,v $
//	Version:	$Revision: 1.2 $
//	Desc:		Lab3 Code Comparator
//	Author:		Greg Gibeling
//	Copyright:	Copyright 2003-2004 UC Berkeley
//	This copyright header must appear in all derivative works.
//-----------------------------------------------------------------------

//-----------------------------------------------------------------------
//	Section:	Change Log
//-----------------------------------------------------------------------
//	$Log: Lab3Compare.v,v $
//	Revision 1.2  2004/07/08 21:53:11  Administrator
//	Added combo reprogramming
//	Implemented and Tested
//	
//	Revision 1.1  2004/07/08 18:41:26  Administrator
//	Initial Import
//	Completed
//	Fully Tested
//	
//-----------------------------------------------------------------------

//-----------------------------------------------------------------------
//	Module:		Lab3Compare
//	Desc:		This module is responsible for generating the
//			Decode1&2 signals which actually cause the FSM to
//			change states.  This allows for more flexibility
//			in changing the code.
//-----------------------------------------------------------------------
module Lab3Compare(Code, Decode1, Decode2, Prog1, Prog2, Enable, Clock, Reset);
	//---------------------------------------------------------------
	//	Code Input
	//---------------------------------------------------------------
	input	[1:0]		Code;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	Decoded Outputs
	//---------------------------------------------------------------
	output			Decode1, Decode2;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	Controls for Reprogramming the Combo
	//---------------------------------------------------------------
	input			Prog1, Prog2, Enable;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	System Inputs
	//---------------------------------------------------------------
	input			Clock, Reset;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	Regs
	//---------------------------------------------------------------
	reg	[1:0]		Code1, Code2;
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	Decode
	//		These assign statements are the easiest way to
	//		decode the input.
	//---------------------------------------------------------------
	assign			Decode1 =		(Code == Code1);
	assign			Decode2 =		(Code == Code2);
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	Code1 Register
	//---------------------------------------------------------------
	always @ (posedge Clock) begin
		if (Reset) Code1 <=			2'b11;		// Set up the default combination
		else if (Prog1 & Enable) Code1 <=	Code;
	end
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	Code2 Register
	//---------------------------------------------------------------
	always @ (posedge Clock) begin
		if (Reset) Code2 <=			2'b01;
		else if (Prog2 & Enable) Code2 <=	Code;
	end
	//---------------------------------------------------------------
endmodule
//-----------------------------------------------------------------------